from KwoksTool.info import (welcome,how)
from KwoksTool.function import (GetCityNumFromLiepin,
                                GetCityNumFromBossZhiPing,
                                GetCityNameFromLiepin,
                                YesOrNot,
                                CheckIp,
                                IntoZip,
                                ZipOut,
                                SendEmail,
                                GetEmail,
                                ProgressBar,
                                MergeTable,
                                ChoiceColumn)
from KwoksTool.source.IpPool import GetIpPool
from KwoksTool.model import (GetProbMatrix,ToMat)
from KwoksTool.spider import (Browser, PlateComponentStocks)
from KwoksTool.Spider.stock import GetStocksData
class spider:
    from KwoksTool.Spider.function import (find_diffrent_key_from_str)
    from KwoksTool.source.IpPool import (get_ip_from_shop)
class show:
    from KwoksTool.Show.function import (SelecTHead,px_to_percent)
class function:
    from KwoksTool.function import (PackageWithoutBorderBorder,Package,DeleteAll,PackageService)
dependencies=[
    'altgraph==0.17.3',
    'attrs==23.1.0',
    'beautifulsoup4==4.12.2',
    'bleach==6.0.0',
    'blinker==1.6.2',
    'bs4==0.0.1',
    'build==0.10.0',
    'certifi==2023.7.22',
    'cffi==1.15.1',
    'charset-normalizer==3.2.0',
    'click==8.1.6',
    'colorama==0.4.6',
    'docutils==0.20.1',
    'et-xmlfile==1.1.0',
    'exceptiongroup==1.1.2',
    'Flask==2.3.2',
    'h11==0.14.0',
    'idna==3.4',
    'importlib-metadata==6.8.0',
    'itsdangerous==2.1.2',
    'jaraco.classes==3.3.0',
    'Jinja2==3.1.2',
    'keyring==24.2.0',
    'lxml==4.9.3',
    'markdown-it-py==3.0.0',
    'MarkupSafe==2.1.3',
    'mdurl==0.1.2',
    'more-itertools==10.1.0',
    'numpy==1.25.2',
    'openpyxl==3.1.2',
    'outcome==1.2.0',
    'packaging==23.1',
    'pandas==2.0.3',
    'pefile==2023.2.7',
    'pkginfo==1.9.6',
    'prettytable==3.8.0',
    'pycparser==2.21',
    'pyecharts==2.0.3',
    'PyExecJS==1.5.1',
    'Pygments==2.16.1',
    'pyinstaller==5.13.0',
    'pyinstaller-hooks-contrib==2023.6',
    'pyproject_hooks==1.0.0',
    'PySocks==1.7.1',
    'python-dateutil==2.8.2',
    'pytz==2023.3',
    'pywin32-ctypes==0.2.2',
    'readme-renderer==40.0',
    'requests==2.31.0',
    'requests-toolbelt==1.0.0',
    'rfc3986==2.0.0',
    'rich==13.5.2',
    'selenium==4.9.0',
    'simplejson==3.19.1',
    'six==1.16.0',
    'sniffio==1.3.0',
    'sortedcontainers==2.4.0',
    'soupsieve==2.4.1',
    'tomli==2.0.1',
    'trio==0.22.2',
    'trio-websocket==0.10.3',
    'tushare==1.2.89',
    'twine==4.0.2',
    'tzdata==2023.3',
    'urllib3==1.26.16',
    'wcwidth==0.2.6',
    'webencodings==0.5.1',
    'websocket-client==0.57.0',
    'Werkzeug==2.3.6',
    'wsproto==1.2.0',
    'zipp==3.16.2',
    'xlrd==2.0.1',
    'matplotlib==3.7.2'
]